aboutsummaryrefslogtreecommitdiffstats
path: root/systems/rhel/7.2/build_base_machine.sh
diff options
context:
space:
mode:
Diffstat (limited to 'systems/rhel/7.2/build_base_machine.sh')
-rwxr-xr-xsystems/rhel/7.2/build_base_machine.sh14
1 files changed, 8 insertions, 6 deletions
diff --git a/systems/rhel/7.2/build_base_machine.sh b/systems/rhel/7.2/build_base_machine.sh
index d3f74726..c0f367ab 100755
--- a/systems/rhel/7.2/build_base_machine.sh
+++ b/systems/rhel/7.2/build_base_machine.sh
@@ -53,7 +53,6 @@ pkglist=(
numactl\
numactl-devel\
libpng-devel\
- epel-release\
sshpass\
)
@@ -63,6 +62,9 @@ pkglist=(
python-six\
)
+# install RHEL compatible epel for sshpass
+yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
+
# Iterate installing each package. If packages fail to install, record those
# packages and exit with an error message on completion. Customer may need to
# add repo locations and subscription levels.
@@ -91,14 +93,14 @@ enabled=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-SCLo
EOT
# install python34 packages and git-review tool
yum -y install $(echo "
-rh-python34
-rh-python34-python-tkinter
+rh-python36
+rh-python36-python-tkinter
" | grep -v ^#)
-# cleanup python 34 repo file
-rm -f /etc/yum.repos.d/python34.repo
+# cleanup python 36 repo file
+rm -f /etc/yum.repos.d/python36.repo
# Create hugepage dirs
mkdir -p /dev/hugepages
@@ -91,14 +93,14 @@ enabled=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-SCLo
EOT
-# install python34 packages and git-review tool
+# install python36 packages and git-review tool
yum -y install $(echo "